==> calceph_4.0.4.orig.tar.gz: calceph-calceph_4_0_4/jenkins/extra_check.sh <==
#! /bin/bash
#/*-----------------------------------------------------------------*/
#/*! 
#  \file extra_check.sh
#  \brief Perform some extra tests (requires internet connection). 
#  \author  M. Gastineau 
#           Astronomie et Systemes Dynamiques, IMCCE, CNRS, Observatoire de Paris. 
#
#   Copyright, 2024, CNRS
#   email of the author : Mickael.Gastineau@obspm.fr
#  
#*/
#/*-----------------------------------------------------------------*/
#
#/*-----------------------------------------------------------------*/
#/* License  of this file :
#  This file is "triple-licensed", you have to choose one  of the three licenses 
#  below to apply on this file.
#  
#     CeCILL-C
#     	The CeCILL-C license is close to the GNU LGPL.
#     	( http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html )
#   
#  or CeCILL-B
#        The CeCILL-B license is close to the BSD.
#        (http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt)
#  
#  or CeCILL v2.1
#       The CeCILL license is compatible with the GNU GPL.
#       ( http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.html )
#  
# 
# This library is governed by the CeCILL-C, CeCILL-B or the CeCILL license under 
# French law and abiding by the rules of distribution of free software.  
# You can  use, modify and/ or redistribute the software under the terms 
# of the CeCILL-C,CeCILL-B or CeCILL license as circulated by CEA, CNRS and INRIA  
# at the following URL "http://www.cecill.info". 
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability. 
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or 
# data to be ensured and,  more generally, to use and operate it in the 
# same conditions as regards security. 
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL-C,CeCILL-B or CeCILL license and that you accept its terms.
# */
# /*-----------------------------------------------------------------*/

###################################################################
# perform the extra check
###################################################################
cd tests
../../tests/downloadextra.sh 
cp ../../tests/example1spk_seg*.txt .
echo "checking cmcomputeunit_seg18..." &&  ./cmcomputeunit_seg18 && echo "ok" || exit 1
echo "checking cmcomputeunit_seg5..." &&  ./cmcomputeunit_seg5 && echo "ok" || exit 1
echo "checking cmcomputeunit_seg18..." &&  ./cmcomputeunit_seg18 && echo "ok" || exit 1
echo "checking cmcomputeunit_seg20..." &&  ./cmcomputeunit_seg20 && echo "ok" || exit 1
cd ..

==> calceph_4.0.5.orig.tar.gz: calceph-calceph_4_0_5/jenkins/extra_check.sh <==
#! /bin/bash
#/*-----------------------------------------------------------------*/
#/*! 
#  \file extra_check.sh
#  \brief Perform some extra tests (requires internet connection). 
#  \author  M. Gastineau 
#           Astronomie et Systemes Dynamiques, LTE, CNRS, Observatoire de Paris. 
#
#   Copyright, 2024-2025, CNRS
#   email of the author : Mickael.Gastineau@obspm.fr
#  
#*/
#/*-----------------------------------------------------------------*/
#
#/*-----------------------------------------------------------------*/
#/* License  of this file :
#  This file is "triple-licensed", you have to choose one  of the three licenses 
#  below to apply on this file.
#  
#     CeCILL-C
#     	The CeCILL-C license is close to the GNU LGPL.
#     	( http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html )
#   
#  or CeCILL-B
#        The CeCILL-B license is close to the BSD.
#        (http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt)
#  
#  or CeCILL v2.1
#       The CeCILL license is compatible with the GNU GPL.
#       ( http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.html )
#  
# 
# This library is governed by the CeCILL-C, CeCILL-B or the CeCILL license under 
# French law and abiding by the rules of distribution of free software.  
# You can  use, modify and/ or redistribute the software under the terms 
# of the CeCILL-C,CeCILL-B or CeCILL license as circulated by CEA, CNRS and INRIA  
# at the following URL "http://www.cecill.info". 
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability. 
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or 
# data to be ensured and,  more generally, to use and operate it in the 
# same conditions as regards security. 
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL-C,CeCILL-B or CeCILL license and that you accept its terms.
# */
# /*-----------------------------------------------------------------*/

###################################################################
# perform the extra check
###################################################################
cd tests
../../tests/downloadextra.sh 
cp ../../tests/example1spk_seg*.txt .
echo "checking cmcomputeunit_seg5..." &&  ./cmcomputeunit_seg5 && echo "ok" || exit 1
echo "checking cmcomputeunit_seg17..." &&  ./cmcomputeunit_seg17 && echo "ok" || exit 1
echo "checking cmcomputeunit_seg18..." &&  ./cmcomputeunit_seg18 && echo "ok" || exit 1
echo "checking cmcomputeunit_seg19..." &&  ./cmcomputeunit_seg19 && echo "ok" || exit 1
echo "checking cmcomputeunit_seg20..." &&  ./cmcomputeunit_seg20 && echo "ok" || exit 1
cd ..
